@@ -9,6 +9,7 @@ from scipy.optimize import brentq
 from rcdesign.is456.stressblock import LSMStressBlock
 from rcdesign.is456.concrete import Concrete
 from rcdesign.is456.rebar import (
+    BentupBars,
     RebarHYSD,
     RebarLayer,
     RebarGroup,
@@ -27,11 +28,7 @@ t2 = RebarLayer(fe415, [16, 16], -70)
 c1 = RebarLayer(fe415, [16, 16], 35)
 c2 = RebarLayer(fe415, [16, 16], 70)
 c3 = RebarLayer(fe415, [12, 12], 100)
-# t_st = RebarGroup(fe415, [t1, t2])
-# c_st = RebarGroup(fe415, [c1, c2])
-t_st = None
-c_st = None
-sh_st = ShearRebarGroup([Stirrups(fe415, 2, 8, 150)])
+sh_st = ShearRebarGroup([Stirrups(fe415, 2, 8, 150), BentupBars(fe415, [16, 16])])
 long_st = RebarGroup([t2, c1, t1, c2])
 
 sec = RectBeamSection(230, 500, sb, m20, long_st, sh_st, 25)
